@@ -6,6 +6,7 @@ class EFeatureId(Enum):
   PID=1
   MOD_BUS=2
   WIFI=3
+  AIR_QUALITY_SGP30=4
   SER_UNKNOWN=-1
 
   @staticmethod
@@ -17,5 +18,13 @@ class EFeatureId(Enum):
 
     return EFeatureId.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EFeatureId':
+    try:
+      return EFeatureId[name]
+    except KeyError:
+      return EFeatureId.SER_UNKNOWN 
+
+
 
 
