@@ -3,6 +3,7 @@ from enum import Enum
 
 class EErrorCode(Enum):
   CONFIGURATION_OUT_OF_MEMORY=0
+  ANY_ERROR=255
   SER_UNKNOWN=-1
 
   @staticmethod
@@ -14,5 +15,13 @@ class EErrorCode(Enum):
 
     return EErrorCode.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EErrorCode':
+    try:
+      return EErrorCode[name]
+    except KeyError:
+      return EErrorCode.SER_UNKNOWN 
+
+
 
 
