@@ -15,5 +15,13 @@ class EEnable(Enum):
 
     return EEnable.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EEnable':
+    try:
+      return EEnable[name]
+    except KeyError:
+      return EEnable.SER_UNKNOWN 
+
+
 
 
