@@ -25,5 +25,13 @@ class EMonth(Enum):
 
     return EMonth.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EMonth':
+    try:
+      return EMonth[name]
+    except KeyError:
+      return EMonth.SER_UNKNOWN 
+
+
 
 
