@@ -20,5 +20,13 @@ class EWeekDay(Enum):
 
     return EWeekDay.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EWeekDay':
+    try:
+      return EWeekDay[name]
+    except KeyError:
+      return EWeekDay.SER_UNKNOWN 
+
+
 
 
