@@ -16,5 +16,13 @@ class EState(Enum):
 
     return EState.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EState':
+    try:
+      return EState[name]
+    except KeyError:
+      return EState.SER_UNKNOWN 
+
+
 
 
